@@ -26,7 +26,7 @@ package Ftree::Name;
 use strict;
 use warnings;
 use Ftree::TextGeneratorFactory qw(getTextGenerator get_reverse_name);
-use version; our $VERSION = qv('2.3.33');
+use version; our $VERSION = qv('2.3.34');
 
 use Params::Validate qw(:all);
 
@@ -114,6 +114,9 @@ __END__
 
 Ftree - family tree generator
 
+=for html
+<a href="https://travis-ci.org/mishin/Ftree-cpan"><img src="https://travis-ci.org/mishin/Ftree-cpan.svg?branch=master"></a>
+
 =head1 EXAMPLE
 
 L<https://still-lowlands-7377.herokuapp.com>
@@ -124,26 +127,11 @@ installator for Windows 7 32bit
 L<https://sourceforge.net/projects/family-tree-32/files/latest/download?source=navbar>
 
   #If install it
-  cpanm FamilyTreeInfo
-
-  #copy the folder cgi-bin from the distribution
-  cp cgi-bin c:\ftree\cgi-bin
-
-  #then got to it directory
-  c:\ftree\cgi-bin
-  #and run
-  plackup
-
-  #HTTP::Server::PSGI: Accepting connections at http://0:5000/
-
-  #now go to the browser
-  http://127.0.0.1:5000/
-
-  try to attach junit to eclipse
-
-  http://blogs.perl.org/users/confuseacat/2011/09/perl-testing-with-jenkinshudson-avoiding-some-pitfalls.html
-  prove -r --timer --formatter=TAP::Formatter::JUnit -l t > test_results.xml
+  cpanm M/MI/MISHIN/FamilyTreeInfo-2.3.33.tar.gz
 
+  git clone https://github.com/mishin/Ftree-cpan.git
+  cd Ftree-cpan/cgi-bin
+  ftree.bat
 
 
   #and we can see a family tree, and
